==> alg-common-3.1.6-20191231.081740-9-sources.jar: cn/com/duiba/nezha/alg/common/model/materialrecommend/Constant.java <==
package cn.com.duiba.nezha.alg.common.model.materialrecommend;

/**
 * @author lijingzhe
 * @description 参数
 * @date 2019/12/12
 */
public class Constant {
    /**
     * 新素材试投概率
     */
    static double PROB = 0.001;
    /**
     * 新素材曝光阈值
     */
    static int EXPOSURE_THRESHOLD = 200;
    /**
     * 新素材点击阈值
     */
    static int CLICK_THRESHOLD = 30;
    /**
     * 海选召回数量
     */
    static int RECALL_TOPN = 50;
    /**
     * 全局ctr召回数量
     */
    static int RECALL_GCTR_TOPN = 10;
    /**
     * 广告位ctr召回数量
     */
    static int RECALL_SCTR_TOPN = 10;
    /**
     * 全局每pv消耗召回数量
     */
    static int RECALL_GUC_TOPN = 10;
    /**
     * 广告位每pv消耗召回数量
     */
    static int RECALL_SUC_TOPN = 10;
    /**
     * 优质素材召回数量
     */
    static int EXCELLENT_TOPN = 10;
    /**
     * 最小收益
     */
    static double MIN_REWARD = 0.1;
    /**
     * beta分布参数
     */
   static double DECAY = 0.99;
    /**
     * 素材扶持阈值
     */
    static int FC_THRESHOLD = 200;
    /**
     * 优质素材扶持概率
     */
    static double EXCELLENT_FC_PROB = 0.06;
    /**
     * ctr高(top 2-5)素材扶持概率
     */
    static double CTR_FC_PROB = 0.04;
    /**
     * 素材兜底阈值
     */
    static int DD_THRESHOLD = 500;
    /**
     * 优质素材(top 2-5)兜底概率
     */
    static double DD_PROB_HIGH = 0.02;
    /**
     * 优质素材(top 5-15)兜底概率
     */
    static double DD_PROB_MID = 0.02;
    /**
     * 优质素材(top 15-30)兜底概率
     */
    static double DD_PROB_LOW = 0.015;
    /**
     * 组合推荐状态参数CTR
     */
    static String ALG_CTR = "ctr";
    /**
     * 组合推荐状态参数
     */
    static String ALG_UC = "uc";
}

==> alg-common-22.12.28-20221229.015545-1-sources.jar: cn/com/duiba/nezha/alg/common/model/materialrecommend/Constant.java <==
package cn.com.duiba.nezha.alg.common.model.materialrecommend;

/**
 * @author lijingzhe
 * @description 参数
 * @date 2019/12/12
 */
public class Constant {
    /**
     * 新素材试投概率
     */
    static double PROB = 0.001;
    /**
     * 新素材曝光阈值
     */
    static int EXPOSURE_THRESHOLD = 200;
    /**
     * 新素材点击阈值
     */
    static int CLICK_THRESHOLD = 30;
    /**
     * 2.0海选召回数量
     */
    static int RECALL_TOPN_20 = 50;
    /**
     * 2.5海选召回数量
     */
    static int RECALL_TOPN_25 = 60;
    /**
     * 全局ctr召回数量
     */
    static int RECALL_GCTR_TOPN = 10;
    /**
     * 广告位ctr召回数量
     */
    static int RECALL_SCTR_TOPN = 10;
    /**
     * 全局每访问pv消耗召回数量
     */
    static int RECALL_GUCA_TOPN = 5;
    /**
     * 广告位每访问pv消耗召回数量
     */
    static int RECALL_SUCA_TOPN = 5;
    /**
     * 全局每pv消耗召回数量
     */
    static int RECALL_GUC_TOPN = 10;
    /**
     * 广告位每pv消耗召回数量
     */
    static int RECALL_SUC_TOPN = 10;
    /**
     * 优质素材召回数量
     */
    static int EXCELLENT_TOPN = 10;
    /**
     * 最小收益
     */
    static double MIN_REWARD = 0.1;
    /**
     * beta分布参数
     */
   static double DECAY = 0.99;
    /**
     * 素材扶持阈值
     */
    static int FC_THRESHOLD = 200;
    /**
     * 优质素材扶持概率
     */
    static double EXCELLENT_FC_PROB = 0.06;
    /**
     * ctr高(top 2-5)素材扶持概率
     */
    static double CTR_FC_PROB = 0.04;
    /**
     * 素材兜底阈值
     */
    static int DD_THRESHOLD = 500;
    /**
     * 广告位消耗阈值，分
     */
    static int COST_THRESHOLD = 60000;
    /**
     * 优质素材(top 2-5)兜底概率
     */
    static double DD_PROB_HIGH = 0.02;
    /**
     * 优质素材(top 5-15)兜底概率
     */
    static double DD_PROB_MID = 0.02;
    /**
     * 优质素材(top 15-30)兜底概率
     */
    static double DD_PROB_LOW = 0.015;
    /**
     * 组合推荐状态参数CTR
     */
    static String ALG_CTR = "ctr";
    /**
     * 组合推荐状态参数
     */
    static String ALG_UC = "uc";
    /**
     * 组合推荐状态参数
     */
    static String ALG_UCA = "uca";
    /**
     * 策略=2.0
     */
    static String ALG_TYPE_20 = "alg20";
    /**
     * 策略=2.5
     */
    static String ALG_TYPE_25 = "alg25";
}
